package com.sundot.airport.system.service;

import java.util.List;

import com.sundot.airport.system.domain.BasePerformanceIndicatorCategory;
import com.sundot.airport.system.domain.BasePerformanceIndicatorCategoryTreeDTO;
import com.sundot.airport.system.domain.BasePerformanceIndicatorCategoryTreeRequestDTO;

/**
 * 考核指标分类Service接口
 *
 * @author ruoyi
 * @date 2026-04-28
 */
public interface IBasePerformanceIndicatorCategoryService {
    /**
     * 查询考核指标分类
     *
     * @param id 考核指标分类主键
     * @return 考核指标分类
     */
    public BasePerformanceIndicatorCategory selectBasePerformanceIndicatorCategoryById(Long id);

    /**
     * 查询考核指标分类列表
     *
     * @param basePerformanceIndicatorCategory 考核指标分类
     * @return 考核指标分类集合
     */
    public List<BasePerformanceIndicatorCategory> selectBasePerformanceIndicatorCategoryList(BasePerformanceIndicatorCategory basePerformanceIndicatorCategory);

    /**
     * 新增考核指标分类
     *
     * @param basePerformanceIndicatorCategory 考核指标分类
     * @return 结果
     */
    public int insertBasePerformanceIndicatorCategory(BasePerformanceIndicatorCategory basePerformanceIndicatorCategory);

    /**
     * 修改考核指标分类
     *
     * @param basePerformanceIndicatorCategory 考核指标分类
     * @return 结果
     */
    public int updateBasePerformanceIndicatorCategory(BasePerformanceIndicatorCategory basePerformanceIndicatorCategory);

    /**
     * 批量删除考核指标分类
     *
     * @param ids 需要删除的考核指标分类主键集合
     * @return 结果
     */
    public int deleteBasePerformanceIndicatorCategoryByIds(Long[] ids);

    /**
     * 删除考核指标分类信息
     *
     * @param id 考核指标分类主键
     * @return 结果
     */
    public int deleteBasePerformanceIndicatorCategoryById(Long id);

    /**
     * 查询考核指标分类对象树形结构
     *
     * @param basePerformanceIndicatorCategory 考核指标分类对象
     * @return 树结构列表
     */
    public List<BasePerformanceIndicatorCategory> selectBasePerformanceIndicatorCategoryListTree(BasePerformanceIndicatorCategory basePerformanceIndicatorCategory);

    /**
     * 构建前端所需要树结构
     *
     * @param list 列表
     * @return 树结构列表
     */
    public List<BasePerformanceIndicatorCategory> buildTree(List<BasePerformanceIndicatorCategory> list);

    /**
     * 获取分类树及关联指标（支持模糊查询）
     *
     * @param requestDTO 入参
     * @return 树结构列表
     */
    public List<BasePerformanceIndicatorCategoryTreeDTO> getCategoryTreeWithIndicatorList(BasePerformanceIndicatorCategoryTreeRequestDTO requestDTO);
}
